package com.caimei365.user.mapper;

import com.caimei365.user.model.dto.ShopUpdateDto;
import com.caimei365.user.model.po.ArticlePo;
import com.caimei365.user.model.po.ShopCertPo;
import com.caimei365.user.model.po.UserPo;
import com.caimei365.user.model.vo.*;
import org.apache.ibatis.annotations.MapKey;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/3/16
 */
@Mapper
public interface ShopMapper {

    /**
     * 供应商快捷登录
     * @param userId
     * @return
     */
    UserLoginVo getShopByUserId(Integer userId);
    /**
     * 根据Id查询供应商
     * @param shopId    供应商Id
     * @return ShopVo
     */
    ShopVo getShopById(Integer shopId);

    /**
     * 修改供应商信息保存用户
     * @param user  用户数据
     */
    void updateShopUserByUpdateInfo(UserPo user);

    /**
     * 修改供应商信息保存供应商
     * @param shop  供应商数据
     */
    void updateShopByUpdateInfo(ShopUpdateDto shop);

    /**
     * 根据供应商Id和资质证书类型Id获取供应商资质证书
     * @param shopId            供应商Id
     * @param shopCertTypeId    资质证书类型Id
     * @return String
     */
    List<String> getShopCert(Integer shopId, Integer shopCertTypeId);

    /**
     * 根据供应商Id删除供应商资质证书数据
     * @param shopId    供应商Id
     */
    void deleteShopCertByShopId(Integer shopId);

    /**
     * 保存供应商资质证书
     * @param shopCert  资质证书数据
     */
    void insertShopCert(ShopCertPo shopCert);

    /**
     * 供应商首页数据
     * @param shopId 供应商Id
     */
    ShopHomeVo getShopHomeData(Integer shopId);

    /**
     * 公司资质照片
     */
    List<String> getShopCertById(Integer shopId, int shopCertTypeId);
    /**
     * 医疗器械经营许可
     */
    String medicalPracticeLicense(Integer shopId);

    /**
     * 供应商首页-轮播图片
     */
    List<ShopBannerVo> getShopHomeImages(Integer shopId);
    /**
     * 店铺促销活动
     */
    PromotionsVo getShopPromotionsByShopId(Integer shopId);
    /**
     * 促销赠品
     */
    List<ProductItemVo> getPromotionsGifts(Integer promotionsId);
    /**
     * 统计商品数量
     *
     * @param shopId    供应商id
     * @param productOrganize    上架平台
     * @param validFlag 商品状态
     */
    Integer getShopProductCount(@Param("shopId") Integer shopId, @Param("productOrganize") Integer productOrganize, @Param("validFlag") Integer validFlag);
    /**
     * 统计前五的商品销售信息
     */
    @MapKey("productId")
    List<Map<String, Object>> getSalesRankingList(@Param("shopId") Integer shopId, @Param("organizeId") Integer organizeId);
    /**
     * 获取商品信息
     */
    ProductItemVo getProductShown(Integer productId);
    /**
     * 销售统计
     */
    @MapKey("orderQuantity")
    Map<String, Object> getSalesStatistics(Integer shopId, Integer organizeId, String startTime, String endTime);

    /**
     * 是否为营销供应商
     * @param shopId
     * @return
     */
    Integer getShopIsMark(@Param("shopId") Integer shopId);
    /**
     * 轮播图片数量
     */
    int getShopHomeImageCount(Integer shopId);
    /**
     * 新增轮播图
     */
    void insertShopHomeImage(ShopBannerVo shopBanner);
    /**
     * 更新轮播图
     */
    void updateShopHomeImage(ShopBannerVo shopBanner);
    /**
     * 删除轮播图
     */
    void deleteShopHomeImage(Integer id);
    /**
     * 获取报表对应的供应商信息
     * @param shopId
     * @param type
     * @return
     */
    CmMarketShopVo getShopInfoById(@Param("shopId") Integer shopId, @Param("type") Integer type, @Param("marketReportId") Integer marketReportId);

    /**
     * 营销供应商报表Id
     * @param marketId
     * @param startTime
     * @param endTime
     * @return
     */
    List<Integer> getMarketReportIds(@Param("marketId") Integer marketId, @Param("type") Integer type, @Param("marketReportId") Integer marketReportId, @Param("startTime") String startTime, @Param("endTime") String endTime);

    /**
     * 获取阶段描述
     * @param marketReportIds
     * @return
     */
    List<StageVo> getMarketStage(@Param("marketReportIds") List<Integer> marketReportIds);


    /**
     * 获取漏洞模型数据
     * @param marketReportIds
     * @return
     */
    List<FunnelModelVo> getMarketFunnelModel(@Param("marketReportIds") List<Integer> marketReportIds);

    /**
     * 获取推文数据
     * @param marketReportIds
     * @return
     */
    List<ArticleReadVolumeVo> getMarketArticleReadVolume(@Param("marketReportIds") List<Integer> marketReportIds);

    /**
     * 获取展现量数据
     * @param marketReportIds
     * @return
     */
    List<ImpressionsVo> getMarketImpressions(@Param("marketReportIds") List<Integer> marketReportIds);

    /**
     * 获取点击量数据
     * @param marketReportIds
     * @return
     */
    List<ReadVolumeVo> getMarketReadVolume(@Param("marketReportIds") List<Integer> marketReportIds);

    /**
     * 获取SEO汇总数据
     * @param marketReportIds
     * @return
     */
    List<SummaryVo> getMarketSummary(@Param("marketReportIds") List<Integer> marketReportIds);

    /**
     * 获取访问量数据
     * @param marketReportIds
     * @return
     */
    List<VisitsVo> getMarketVisits(@Param("marketReportIds") List<Integer> marketReportIds);

    /**
     * 获取访客来源分布数据
     * @param marketReportIds
     * @return
     */
    List<ProportionVo> getMarketProportion(@Param("marketReportIds") List<Integer> marketReportIds);

    /**
     * 获取页面平均访问时长数据
     * @param marketReportIds
     * @return
     */
    List<PageDurationVo> getMarketPageDuration(@Param("marketReportIds") List<Integer> marketReportIds);

    /**
     * 获取广告图点击量数据
     * @param marketReportIds
     * @return
     */
    List<AdvertHitsVo> getMarketAdvertHits(@Param("marketReportIds") List<Integer> marketReportIds);

    /**
     * 获取咨询数量数据
     * @param marketReportIds
     * @return
     */
    List<CmMarketRemarkVo> getMarketRemark(@Param("marketReportIds") List<Integer> marketReportIds);

    /**
     * 供应商包含的标签词
     * @param shopId
     * @return
     */
    List<String> getShopKeyword(@Param("shopId") Integer shopId);

    /**
     * 访问供应商相关用户所在地区
     * @param startTime
     * @param endTime
     * @param labels
     * @return
     */
    List<String> getRegion(@Param("startTime") String startTime, @Param("endTime") String endTime, @Param("labels") List<String> labels);

    /**
     * 用户身份
     * @param startTime
     * @param endTime
     * @param labels
     * @return
     */
    List<ReturnEntityVo> getUserIdentity(@Param("startTime") String startTime, @Param("endTime") String endTime, @Param("labels") List<String> labels);

    /**
     * 机构类型
     * @param startTime
     * @param endTime
     * @param labels
     * @return
     */
    List<ReturnEntityVo> getClubType(@Param("startTime") String startTime, @Param("endTime") String endTime, @Param("labels") List<String> labels);

    /**
     * 供应商下有报表的月份集合
     * @param shopId
     * @return
     */
    List<String> getMarketReportDataList(@Param("shopId") Integer shopId);
}
